# TDatabase - اولین دیتابیس ایرانی مستقل 🇮🇷💥

**TDatabase** یک دیتابیس ایرانی مستقل است که به شما امکان می‌دهد داده‌ها را **ذخیره، ویرایش، لود و مدیریت** کنید، بدون نیاز به SQL یا دیتابیس‌های خارجی.  
همراه با **GUI حرفه‌ای** و **کتابخانه پایتون** برای کار راحت توسعه‌دهندگان.

## ویژگی‌ها ✨
- کاملاً مستقل و بومی ✅
- فایل‌های دیتابیس با پسوند `.pxdb` 📦
- مدیریت داده‌ها با **GUI زیبا و ساده** 🖥️
- کتابخانه پایتون برای عملیات CRUD سریع 🐍
- ایجاد، باز کردن، ذخیره و لود دیتابیس جدید بدون دردسر 💾
- سبک و سریع ⚡

## تغییرات 🛠
- اضافه شدن category به دیتا بیس :
میتوانید یک کتگوری برای username و password بسازید و هر کدام رو به دسته بندی 
مورد نظر ارسال کنید . 
- اضافه شدن open به دیتا بیس
میتوانید بدون نیاز به هر بار وارد کردن اسم database یک بار اون رو باز کنید
و تا پایان پروژه از آن استفاده کنید
- آماده  شدن gui برای انتشار
میتونید یک برنامه exe رو نصب و راه اندازی کنید و فایل ها با پسوند .pxdb رو باز کنید
میتونید کتگوری ها و موارد آن را مشاهده کنید
- اضافه شدن گیت هاب 
میتوانید با ادرس زیر وارد سایت گیت هاب ما شوید 
https://github.com/tahagaga/tdatabase
- اضافه شدن hash به دیتا بیس
میتوانید گذینه hash رو برای متن های مورد نظر انتخاب کنید و در صورتی که اون متن رو 
خودتون داشته باشید میتونید اون رو باز کنید که جلو گیری میکنه از دزدی password ها

## نصب 🛠️
```bash
pip install tdatabase
